@@ -1,3 +1,3 @@
-from . import app, api
+from . import api, app
 
-__all__ = ["app", "api"]
\ No newline at end of file
+__all__ = ["app", "api"]
