@@ -3,6 +3,8 @@ import logging
 
 logger = logging.getLogger(__name__)
 
+PROBLEM_MT = "application/problem+json"
+
 
 class CatchAllExceptionMiddleware:
     """ASGI middleware that logs exceptions without breaking streaming (SSE)."""
@@ -11,7 +13,6 @@ class CatchAllExceptionMiddleware:
         self.app = app
 
     async def __call__(self, scope, receive, send):
-        # Only handle HTTP; pass through websockets, lifespan, etc.
         if scope["type"] != "http":
             return await self.app(scope, receive, send)
 
@@ -26,11 +27,9 @@ class CatchAllExceptionMiddleware:
         try:
             await self.app(scope, receive, send_wrapper)
         except Exception as exc:
-            # We can only replace the response if it hasn't started yet.
             logger.exception("Unhandled error on %s", scope.get("path"))
 
             if response_started:
-                # Can't change headers/status mid-stream; best effort to end stream.
                 try:
                     await send({"type": "http.response.body", "body": b"", "more_body": False})
                 except Exception:
@@ -38,15 +37,19 @@ class CatchAllExceptionMiddleware:
             else:
                 body = json.dumps(
                     {
-                        "error": type(exc).__name__,
+                        "type": "about:blank",
+                        "title": "Internal Server Error",
+                        "status": 500,
                         "detail": str(exc),
+                        "instance": scope.get("path", "/"),
+                        "code": "INTERNAL_ERROR",
                     }
                 ).encode("utf-8")
                 await send(
                     {
                         "type": "http.response.start",
                         "status": 500,
-                        "headers": [(b"content-type", b"application/json")],
+                        "headers": [(b"content-type", PROBLEM_MT.encode("ascii"))],
                     }
                 )
                 await send({"type": "http.response.body", "body": body, "more_body": False})
