@@ -8,7 +8,6 @@ from svc_infra.cli.cmds import (
     register_mongo,
     register_mongo_scaffold,
     register_obs,
-    register_redis,
     register_sql_scaffold,
 )
 from svc_infra.cli.foundation.typer_bootstrap import pre_cli
@@ -24,9 +23,6 @@ register_sql_scaffold(app)
 register_mongo(app)
 register_mongo_scaffold(app)
 
-# --- cache commands ---
-register_redis(app)
-
 # -- observability commands ---
 register_obs(app)
 
